@@ -3,27 +3,28 @@
 '''
 utils.py: python helper for singularity command line tool
 
-Copyright (c) 2016, Vanessa Sochat. All rights reserved. 
+Copyright (c) 2016-2017, Vanessa Sochat. All rights reserved.
 
 "Singularity" Copyright (c) 2016, The Regents of the University of California,
 through Lawrence Berkeley National Laboratory (subject to receipt of any
 required approvals from the U.S. Dept. of Energy).  All rights reserved.
- 
+
 This software is licensed under a customized 3-clause BSD license.  Please
 consult LICENSE file distributed with the sources of this project regarding
 your rights to use or distribute this software.
- 
+
 NOTICE.  This Software was developed under funding from the U.S. Department of
 Energy and the U.S. Government consequently retains certain rights. As such,
 the U.S. Government has been granted for itself and others acting on its
 behalf a paid-up, nonexclusive, irrevocable, worldwide license in the Software
 to reproduce, distribute copies to the public, prepare derivative works, and
-perform publicly and display publicly, and to permit other to do so. 
+perform publicly and display publicly, and to permit other to do so.
 
 '''
 
 from defaults import (
-    SINGULARITY_CACHE
+    SINGULARITY_CACHE,
+    DISABLE_HTTPS
 )
 from message import bot
 import datetime
@@ -49,27 +50,28 @@ if sys.version_info[0] < 3:
     from exceptions import OSError
 
 
-############################################################################
-## HTTP OPERATIONS #########################################################
-############################################################################
+####################################################################
+# HTTP OPERATIONS ##################################################
+####################################################################
 
-def add_http(url,use_https=True):
-    '''add_http will add a http / https prefix to a url, in case the user didn't
-    specify
+def add_http(url, use_https=True):
+    '''add_http will add a http / https prefix to a url,
+    in case the user didn't specify
     :param url: the url to add the prefix to
     :param use_https: should we default to https? default is True
     '''
     scheme = "https://"
-    if use_https == False:
-        scheme="http://"
+    if use_https is False or DISABLE_HTTPS is True:
+        scheme = "http://"
 
     # remove scheme from url
-    # urlparse is buggy in Python 2.6 https://bugs.python.org/issue754016, use regex instead
+    # urlparse is buggy in Python 2.6
+    # https://bugs.python.org/issue754016, use regex instead
     parsed = re.sub('.*//', '', url)
 
-    return "%s%s" %(scheme, parsed.rstrip('/'))
+    return "%s%s" % (scheme, parsed.rstrip('/'))
+
 
-    
 def basic_auth_header(username, password):
     '''basic_auth_header will return a base64 encoded header object to
     generate a token
@@ -86,9 +88,9 @@ def basic_auth_header(username, password):
     return auth
 
 
-############################################################################
-## COMMAND LINE OPERATIONS #################################################
-############################################################################
+####################################################################
+# COMMAND LINE OPERATIONS ##########################################
+####################################################################
 
 
 def run_command(cmd):
@@ -96,10 +98,10 @@ def run_command(cmd):
     :param cmd: the command to send, should be a list for subprocess
     '''
     try:
-        bot.verbose2("Running command %s with subprocess" %" ".join(cmd))
-        process = subprocess.Popen(cmd,stdout=subprocess.PIPE)
+        bot.verbose2("Running command %s with subprocess" % " ".join(cmd))
+        process = subprocess.Popen(cmd, stdout=subprocess.PIPE)
     except OSError as error:
-        bot.error("Error with subprocess: %s, returning None" %error)
+        bot.error("Error with subprocess: %s, returning None" % error)
         return None
 
     output = process.communicate()[0]
@@ -109,27 +111,24 @@ def run_command(cmd):
     return output
 
 
-def is_number(image):
-    '''is_number determines if the user is providing a singularity hub
-    number (meaning the id of an image to download) vs a full name)
-    :param image: the image name, after the uri is removed (shub://)
+def clean_up(files):
+    '''clean up will delete a list of files, only if they exist
     '''
-    try:
-        float(image)
-        return True
-    except ValueError:
-        return False
-
-
+    if not isinstance(files, list):
+        files = [files]
 
+    for f in files:
+        if os.path.exists(f):
+            bot.verbose3("Cleaning up %s" % f)
+            os.remove(f)
 
 ############################################################################
-## TAR/COMPRESSION #########################################################
+# TAR/COMPRESSION ##########################################################
 ############################################################################
 
 
-def extract_tar(archive,output_folder):
-    '''extract_tar will extract a tar archive to a specified output folder
+def extract_tar(archive, output_folder):
+    '''extract a tar archive to a specified output folder
     :param archive: the archive file to extract
     :param output_folder: the output folder to extract to
     '''
@@ -141,15 +140,16 @@ def extract_tar(archive,output_folder):
     # Just use command line, more succinct.
     command = ["tar", args, archive, "-C", output_folder, "--exclude=dev/*"]
     if not bot.is_quiet():
-        print("Extracting %s" %archive)
+        print("Extracting %s" % archive)
 
     return run_command(command)
 
 
-def create_tar(files,output_folder=None):
+def create_tar(files, output_folder=None):
     '''create_memory_tar will take a list of files (each a dictionary
-    with name, permission, and content) and write the tarfile (a sha256 sum name 
-    is used) to the output_folder. If there is no output folde specified, the
+    with name, permission, and content) and write the tarfile
+    (a sha256 sum name is used) to the output_folder.
+    If there is no output folde specified, the
     tar is written to a temporary folder.
     '''
     if output_folder is None:
@@ -165,95 +165,95 @@ def create_tar(files,output_folder=None):
         info.mtime = int(datetime.datetime.now().strftime('%s'))
         info.uid = entity["uid"]
         info.gid = entity["gid"]
-        info.uname = entity["uname"] 
+        info.uname = entity["uname"]
         info.gname = entity["gname"]
 
         # Get size from stringIO write
         filey = StringIO()
         content = None
-        try: #python3
+        try:  # python3
             info.size = filey.write(entity['content'])
             content = BytesIO(entity['content'].encode('utf8'))
-        except: #python2
+        except Exception:  # python2
             info.size = int(filey.write(entity['content'].decode('utf-8')))
             content = BytesIO(entity['content'].encode('utf8'))
         pass
-        
+
         if content is not None:
-            addition = {'content':content,
-                        'info':info}
+            addition = {'content': content,
+                        'info': info}
             additions.append(addition)
             contents.append(content)
 
     # Now generate the sha256 name based on content
     if len(additions) > 0:
         hashy = get_content_hash(contents)
-        finished_tar = "%s/sha256:%s.tar.gz" %(output_folder, hashy)
+        finished_tar = "%s/sha256:%s.tar.gz" % (output_folder, hashy)
 
         # Warn the user if it already exists
         if os.path.exists(finished_tar):
-            bot.debug("metadata file %s already exists, will over-write." %(finished_tar))
+            msg = "metadata file %s already exists " % finished_tar
+            msg += "will over-write."
+            bot.debug(msg)
 
         # Add all content objects to file
         tar = tarfile.open(finished_tar, "w:gz")
         for a in additions:
-            tar.addfile(a["info"],a["content"])
+            tar.addfile(a["info"], a["content"])
         tar.close()
 
     else:
-        bot.debug("No contents, environment or labels, for tarfile, will not generate.")
+        msg = "No contents, environment or labels"
+        msg += " for tarfile, will not generate."
+        bot.debug(msg)
 
     return finished_tar
 
 
-
-############################################################################
-## HASHES ##################################################################
-############################################################################
-
+####################################################################
+# HASHES ###########################################################
+####################################################################
 
 def get_content_hash(contents):
     '''get_content_hash will return a hash for a list of content (bytes or other)
     '''
     hasher = hashlib.sha256()
     for content in contents:
-        if isinstance(content,BytesIO):
+        if isinstance(content, BytesIO):
             content = content.getvalue()
-        if not isinstance(content,bytes):
+        if not isinstance(content, bytes):
             content = bytes(content)
-        hasher.update(content) 
+        hasher.update(content)
     return hasher.hexdigest()
 
 
-
-############################################################################
-## FOLDERS #################################################################
-############################################################################
+####################################################################
+# FOLDERS ##########################################################
+####################################################################
 
 
-def get_cache(subfolder=None,quiet=False):
-    '''get_cache will return the user's cache for singularity. The path
-    returned is generated at the start of the run, and returned optionally
-    with a subfolder
-    :param subfolder: a subfolder in the cache base to retrieve, specifically
+def get_cache(subfolder=None, quiet=False):
+    '''get_cache will return the user's cache for singularity.
+    The path returned is generated at the start of the run,
+    and returned optionally with a subfolder
+    :param subfolder: a subfolder in the cache base to retrieve
     '''
 
     # Clean up the path and create
     cache_base = clean_path(SINGULARITY_CACHE)
 
     # Does the user want to get a subfolder in cache base?
-    if subfolder != None:
-        cache_base = "%s/%s" %(cache_base,subfolder)
-        
+    if subfolder is not None:
+        cache_base = "%s/%s" % (cache_base, subfolder)
+
     # Create the cache folder(s), if don't exist
     create_folders(cache_base)
 
     if not quiet:
-        bot.info("Cache folder set to %s" %cache_base)
+        bot.info("Cache folder set to %s" % cache_base)
     return cache_base
 
 
-
 def create_folders(path):
     '''create_folders attempts to get the same functionality as mkdir -p
     :param path: the path to create.
@@ -264,25 +264,25 @@ def create_folders(path):
         if e.errno == errno.EEXIST and os.path.isdir(path):
             pass
         else:
-            bot.error("Error creating path %s, exiting." %path)
+            bot.error("Error creating path %s, exiting." % path)
             sys.exit(1)
 
 
 ############################################################################
-## PERMISSIONS #############################################################
+# PERMISSIONS ##############################################################
 ############################################################################
 
 
-def has_permission(file_path,permission=None):
+def has_permission(file_path, permission=None):
     '''has_writability will check if a file has writability using
     bitwise operations. file_path can be a tar member
     :param file_path: the path to the file, or tar member
     :param permission: the stat permission to check for
     is False)
     '''
-    if permission == None:
+    if permission is None:
         permission = stat.S_IWUSR
-    if isinstance(file_path,tarfile.TarInfo):
+    if isinstance(file_path, tarfile.TarInfo):
         has_permission = file_path.mode & permission
     else:
         st = os.stat(file_path)
@@ -292,8 +292,11 @@ def has_permission(file_path,permission=None):
     return False
 
 
-def change_tar_permissions(tar_file,file_permission=None,folder_permission=None):
-    '''change_tar_permissions changes a permission if 
+def change_tar_permissions(tar_file,
+                           file_permission=None,
+                           folder_permission=None):
+
+    '''change_tar_permissions changes a permission if
     any member in a tarfile file does not have it
     :param file_path the path to the file
     :param file_permission: stat permission to use for files
@@ -302,99 +305,97 @@ def change_tar_permissions(tar_file,file_permission=None,folder_permission=None)
     tar = tarfile.open(tar_file, "r:gz")
 
     # Owner read, write (o+rw)
-    if file_permission == None:
+    if file_permission is None:
         file_permission = stat.S_IRUSR | stat.S_IWUSR
 
     # Owner read, write execute (o+rwx)
-    if folder_permission == None:
-        folder_permission = stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR  
+    if folder_permission is None:
+        folder_permission = stat.S_IRUSR | stat.S_IWUSR | stat.S_IXUSR
 
-
-    # Add owner write permission to all, not symlinks      
+    # Add owner write permission to all, not symlinks
     members = tar.getmembers()
-  
-    if len(members) > 0: 
- 
-        bot.verbose("Fixing permission for %s" %(tar_file))
+
+    if len(members) > 0:
+
+        bot.verbose("Fixing permission for %s" % tar_file)
 
         # Add all content objects to file
         fd, tmp_tar = tempfile.mkstemp(prefix=("%s.fixperm." % tar_file))
         os.close(fd)
         fixed_tar = tarfile.open(tmp_tar, "w:gz")
 
-        for member in members:  
+        for member in members:
 
             # add o+rwx for directories
             if member.isdir() and not member.issym():
                 member.mode = folder_permission | member.mode
-                extracted = tar.extractfile(member)        
-                fixed_tar.addfile(member, extracted)        
+                extracted = tar.extractfile(member)
+                fixed_tar.addfile(member, extracted)
 
             # add o+rw for plain files
             elif member.isfile() and not member.issym():
                 member.mode = file_permission | member.mode
-                extracted = tar.extractfile(member)        
+                extracted = tar.extractfile(member)
                 fixed_tar.addfile(member, extracted)
-            else:    
+            else:
                 fixed_tar.addfile(member)
 
         fixed_tar.close()
         tar.close()
- 
+
         # Rename the fixed tar to be the old name
         os.rename(tmp_tar, tar_file)
     else:
         tar.close()
-        bot.warning("Tar file %s is empty, skipping." %(tar_file))
+        bot.warning("Tar file %s is empty, skipping." % tar_file)
 
-    return tar_file        
-        
+    return tar_file
 
 ############################################################################
-## FILES ###################################################################
+# FILES ####################################################################
 ############################################################################
 
 
-def write_file(filename,content,mode="w"):
-    '''write_file will open a file, "filename" and write content, "content"
-    and properly close the file
+def write_file(filename, content, mode="w"):
+    '''write_file will open a file, "filename"
+    and write content, "content" and properly close the file
     '''
-    bot.verbose2("Writing file %s with mode %s." %(filename,mode))
-    with open(filename,mode) as filey:
+    bot.verbose2("Writing file %s with mode %s." % (filename, mode))
+    with open(filename, mode) as filey:
         filey.writelines(content)
     return filename
 
 
-def write_json(json_obj,filename,mode="w",print_pretty=True):
+def write_json(json_obj, filename, mode="w", print_pretty=True):
     '''write_json will (optionally,pretty print) a json object to file
     :param json_obj: the dict to print to json
     :param filename: the output file to write to
-    :param pretty_print: if True, will use nicer formatting   
+    :param pretty_print: if True, will use nicer formatting
     '''
-    bot.verbose2("Writing json file %s with mode %s." %(filename,mode))
-    with open(filename,mode) as filey:
-        if print_pretty == True:
+    bot.verbose2("Writing json file %s with mode %s." % (filename, mode))
+    with open(filename, mode) as filey:
+        if print_pretty is True:
             filey.writelines(print_json(json_obj))
         else:
             filey.writelines(json.dumps(json_obj))
     return filename
 
 
-def read_json(filename,mode='r'):
+def read_json(filename, mode='r'):
     '''read_json reads in a json file and returns
     the data structure as dict.
     '''
-    with open(filename,mode) as filey:
+    with open(filename, mode) as filey:
         data = json.load(filey)
     return data
 
 
-def read_file(filename,mode="r",readlines=True):
-    '''write_file will open a file, "filename" and write content, "content"
-    and properly close the file
+def read_file(filename, mode="r", readlines=True):
+    '''read_file will open a file, "filename" and
+    read content, "content" and properly close the file
     '''
-    bot.verbose3("Reading file %s with mode %s." %(filename,mode))
-    with open(filename,mode) as filey:
+    bot.verbose3("Reading file %s with mode %s." % (filename, mode))
+    with open(filename, mode) as filey:
         if readlines:
             content = filey.readlines()
         else:
@@ -402,7 +403,7 @@ def read_file(filename,mode="r",readlines=True):
     return content
 
 
-def print_json(content,print_console=False):
+def print_json(content, print_console=False):
     '''print_json is intended to pretty print a json
     :param content: the dictionary to print
     :param print_console: if False, return the dump as string (default)
@@ -420,7 +421,7 @@ def clean_path(path):
     return os.path.realpath(path.strip(" "))
 
 
-def get_fullpath(file_path,required=True):
+def get_fullpath(file_path, required=True):
     '''get_fullpath checks if a file exists, and returns the
     full path to it if it does. If required is true, an error is triggered.
     :param file_path: the path to check
@@ -431,16 +432,16 @@ def get_fullpath(file_path,required=True):
         return file_path
 
     # If file is required, we exit
-    if required == True:
-        bot.error("Cannot find file %s, exiting." %file_path)
+    if required is True:
+        bot.error("Cannot find file %s, exiting." % file_path)
         sys.exit(1)
 
     # If file isn't required and doesn't exist, return None
-    bot.warning("Cannot find file %s" %file_path)
+    bot.warning("Cannot find file %s" % file_path)
     return None
 
 
-def get_next_infos(base_dir,prefix,start_number,extension):
+def get_next_infos(base_dir, prefix, start_number, extension):
     '''get_next infos will browse some directory and return
     the next available file
     '''
@@ -449,17 +450,22 @@ def get_next_infos(base_dir,prefix,start_number,extension):
     found = False
 
     while not found:
-        output_file = "%s/%s-%s%s" %(base_dir,
-                                     counter,
-                                     prefix,
-                                     extension)
+        output_file = "%s/%s-%s%s" % (base_dir,
+                                      counter,
+                                      prefix,
+                                      extension)
         if not os.path.exists(output_file):
             found = True
-        counter+=1
+        counter += 1
     return output_file
 
 
-def write_singularity_infos(base_dir,prefix,start_number,content,extension=None):
+def write_singularity_infos(base_dir,
+                            prefix,
+                            start_number,
+                            content,
+                            extension=None):
+
     '''write_singularity_infos will write some metadata object
     to a file in some base, starting at some default number. For example,
     we would want to write dockerN files with docker environment exports to
@@ -470,17 +476,22 @@ def write_singularity_infos(base_dir,prefix,start_number,content,extension=None)
     :param content: the content to write
     :param extension: the extension to use. If not defined, uses .sh
     '''
-    if extension == None:
+    if extension is None:
         extension = ""
     else:
-        extension = ".%s" %(extension)
+        extension = ".%s" % extension
 
     # if the base directory doesn't exist, exit with error.
     if not os.path.exists(base_dir):
-        bot.warning("Cannot find required metadata directory %s. Exiting!" %base_dir)
+        msg = "Cannot find required metadata directory"
+        msg = "%s %s. Exiting!" % (msg, base_dir)
+        bot.warning(msg)
         sys.exit(1)
 
     # Get the next available number
-    output_file = get_next_infos(base_dir,prefix,start_number,extension)
-    write_file(output_file,content)
+    output_file = get_next_infos(base_dir,
+                                 prefix,
+                                 start_number,
+                                 extension)
+    write_file(output_file, content)
     return output_file
