@@ -62,13 +62,13 @@ int container_file_bind(char *source, char *dest_path) {
 
     singularity_priv_escalate();
     singularity_message(VERBOSE, "Binding file '%s' to '%s'\n", source, dest);
-    if ( mount(source, dest, NULL, MS_BIND|MS_NOSUID|MS_REC, NULL) < 0 ) {
+    if ( mount(source, dest, NULL, MS_BIND|MS_NOSUID|MS_NODEV|MS_REC, NULL) < 0 ) {
         singularity_priv_drop();
         singularity_message(ERROR, "There was an error binding %s to %s: %s\n", source, dest, strerror(errno));
         ABORT(255);
     }
     if ( singularity_priv_userns_enabled() != 1 ) {
-        if ( mount(NULL, dest, NULL, MS_BIND|MS_NOSUID|MS_REC|MS_REMOUNT, NULL) < 0 ) {
+        if ( mount(NULL, dest, NULL, MS_BIND|MS_NOSUID|MS_NODEV|MS_REC|MS_REMOUNT, NULL) < 0 ) {
             singularity_priv_drop();
             singularity_message(ERROR, "There was an error remounting %s to %s: %s\n", source, dest, strerror(errno));
             ABORT(255);
