@@ -70,7 +70,7 @@ int _singularity_runtime_mount_binds(void) {
         singularity_message(VERBOSE2, "Found 'bind path' = %s, %s\n", source, dest);
 
         if ( ( is_file(source) < 0 ) && ( is_dir(source) < 0 ) ) {
-            singularity_message(WARNING, "Non existant 'bind path' source: '%s'\n", source);
+            singularity_message(WARNING, "Non existent 'bind path' source: '%s'\n", source);
             continue;
         }
 
@@ -111,7 +111,7 @@ int _singularity_runtime_mount_binds(void) {
                 }
                 singularity_message(DEBUG, "Created bind file: %s\n", dest);
             } else {
-                singularity_message(WARNING, "Non existant bind point (file) in container: '%s'\n", dest);
+                singularity_message(WARNING, "Non existent bind point (file) in container: '%s'\n", dest);
                 continue;
             }
         } else if ( ( is_dir(source) == 0 ) && ( is_dir(joinpath(container_dir, dest)) < 0 ) ) {
@@ -125,19 +125,19 @@ int _singularity_runtime_mount_binds(void) {
                 }
                 singularity_priv_drop();
             } else {
-                singularity_message(WARNING, "Non existant bind point (directory) in container: '%s'\n", dest);
+                singularity_message(WARNING, "Non existent bind point (directory) in container: '%s'\n", dest);
                 continue;
             }
         }
 
         singularity_priv_escalate();
         singularity_message(VERBOSE, "Binding '%s' to '%s/%s'\n", source, container_dir, dest);
-        if ( mount(source, joinpath(container_dir, dest), NULL, MS_BIND|MS_NOSUID|MS_REC, NULL) < 0 ) {
+        if ( mount(source, joinpath(container_dir, dest), NULL, MS_BIND|MS_NOSUID|MS_NODEV|MS_REC, NULL) < 0 ) {
             singularity_message(ERROR, "There was an error binding the path %s: %s\n", source, strerror(errno));
             ABORT(255);
         }
         if ( singularity_priv_userns_enabled() != 1 ) {
-            if ( mount(NULL, joinpath(container_dir, dest), NULL, MS_BIND|MS_NOSUID|MS_REC|MS_REMOUNT, NULL) < 0 ) {
+            if ( mount(NULL, joinpath(container_dir, dest), NULL, MS_BIND|MS_NOSUID|MS_NODEV|MS_REC|MS_REMOUNT, NULL) < 0 ) {
                 singularity_message(ERROR, "There was an error remounting the path %s: %s\n", source, strerror(errno));
                 ABORT(255);
             }
